translate.services.tmserver

Package translate :: Package services :: Module tmserver |
[hide private]
[frames] | no frames]

# Module tmserver

source code

A translation memory server using tmdb for storage, communicates with clients using JSON over HTTP.

Classes | [hide private]
| TMServer A RESTful JSON TM server.

Functions | [hide private]
main() | source code

Imports: urllib, StringIO, logging, sys, parse_qs, OptionParser, json, simple_server, selector, wsgi, factory, base, tmdb